@@ -600,16 +600,21 @@ uc_list(char_u *name, size_t name_len)
 		msg_putchar('|');
 		--len;
 	    }
-	    while (len-- > 0)
-		msg_putchar(' ');
+	    if (len != 0)
+		msg_puts(&"    "[4 - len]);
 
 	    msg_outtrans_attr(cmd->uc_name, HL_ATTR(HLF_D));
 	    len = (int)cmd->uc_namelen + 4;
 
-	    do {
-		msg_putchar(' ');
-		++len;
-	    } while (len < 22);
+	    if (len < 21)
+	    {
+		// Field padding spaces   12345678901234567
+		static char spaces[18] = "                 ";
+		msg_puts(&spaces[len - 4]);
+		len = 21;
+	    }
+	    msg_putchar(' ');
+	    ++len;
 
 	    // "over" is how much longer the name is than the column width for
 	    // the name, we'll try to align what comes after.
@@ -626,7 +631,8 @@ uc_list(char_u *name, size_t name_len)
 		case (EX_EXTRA|EX_NOSPC|EX_NEEDARG): IObuff[len++] = '1'; break;
 	    }
 
-	    do {
+	    do
+	    {
 		IObuff[len++] = ' ';
 	    } while (len < 5 - over);
 
@@ -649,7 +655,8 @@ uc_list(char_u *name, size_t name_len)
 		    IObuff[len++] = '.';
 	    }
 
-	    do {
+	    do
+	    {
 		IObuff[len++] = ' ';
 	    } while (len < 8 - over);
 
@@ -663,7 +670,8 @@ uc_list(char_u *name, size_t name_len)
 		    break;
 		}
 
-	    do {
+	    do
+	    {
 		IObuff[len++] = ' ';
 	    } while (len < 13 - over);
 
@@ -688,7 +696,8 @@ uc_list(char_u *name, size_t name_len)
 #endif
 	    }
 
-	    do {
+	    do
+	    {
 		IObuff[len++] = ' ';
 	    } while (len < 25 - over);
 
